/*
CopySongInfo (main file)

Author: Stanislav Nikolov
Email: valsinats@gmail.com
Version: 0.2
Date: 11.10.2009
License: GPL v2
*/

Importer.loadQtBinding("qt.core");
Importer.loadQtBinding("qt.gui");
Importer.loadQtBinding("qt.uitools");

var settingsDialog; // QDialog -> the configuration dialog

var formatString; // string -> the formatting string, which specifies the copy format
var XSelection; // bool -> if the string is to be copied to the X Selection Buffer
var Clipboard; // bool -> if the string is to be copied to the X Clipboard

// Ease the boolean conversion when reading the settings
String.prototype.toBool = function() { return (/^true$/i).test(this); }; 

Amarok.Window.addToolsSeparator();
Amarok.Window.addToolsMenu("CopySongInfo", "Copy Current Song Info", "edit-copy");
Amarok.Window.ToolsMenu.CopySongInfo['triggered()'].connect( onCopySongInfo );

Amarok.Window.addSettingsMenu("CopySongInfoSettings", "Copy Song Info Settings", "configure");
Amarok.Window.SettingsMenu.CopySongInfoSettings['triggered()'].connect( onCopySongInfoSettings );

loadSettingsUi();

function loadSettingsUi()
{
  var uiLoader = new QUiLoader(this);
  var uiFile = new QFile(Amarok.Info.scriptPath() + "/settings.ui");

  // load file
  uiFile.open(QIODevice.ReadOnly);
  settingsDialog = uiLoader.load(uiFile, this);
  settingsDialog['accepted'].connect( writeSettings );
  uiFile.close();

  readSettings();
}

function onCopySongInfo()
{
  var msg = formatString;

  msg = msg.replace("%A", Amarok.Engine.currentTrack().artist);
  msg = msg.replace("%T", Amarok.Engine.currentTrack().title);
  msg = msg.replace("%P", Amarok.Engine.currentTrack().album);
  
  var trackLen = Amarok.Engine.currentTrack().length;
  var formattedTrackLen = Math.floor(trackLen/60) + ':' + 
    (trackLen%60 < 10 ? '0' : '') + trackLen%60;
  msg = msg.replace("%D", formattedTrackLen);

  if (XSelection)
    QApplication.clipboard().setText(msg, QClipboard.Selection);

  if (Clipboard)
    QApplication.clipboard().setText(msg, QClipboard.Clipboard);

  var osdText;

  if (XSelection && Clipboard)  
    osdText = "Song info copied to both buffers.";  
  else if (XSelection)  
    osdText = "Song info copied to the X Selection";
  else if (Clipboard)  
    osdText = "Song info copied to the X Clipboard";  
  else  
    osdText = "*** No copy destination selected!";  

  Amarok.Window.OSD.setText(osdText);
  Amarok.Window.OSD.show();
}

function onCopySongInfoSettings()
{
  readSettings();

  settingsDialog.show();
}

function readSettings()
{
  formatString = Amarok.Script.readConfig("formatString", "%A - %T");
  settingsDialog.copyFormat.formatString.setText(formatString);

  XSelection = Amarok.Script.readConfig("XSelection", "true").toBool();
  Clipboard  = Amarok.Script.readConfig("Clipboard", "true").toBool();

  settingsDialog.copyDestination.XSelection.checked = XSelection;
  settingsDialog.copyDestination.Clipboard.checked = Clipboard;
}

function writeSettings()
{
  formatString = settingsDialog.copyFormat.formatString.text;
  Amarok.Script.writeConfig("formatString", formatString);

  XSelection = settingsDialog.copyDestination.XSelection.checked;
  Amarok.Script.writeConfig("XSelection", String(XSelection));

  Clipboard = settingsDialog.copyDestination.Clipboard.checked;
  Amarok.Script.writeConfig("Clipboard", String(Clipboard));
}